@@ -3,6 +3,8 @@ This document contains some base functionality for the GUI.
 It contains a function to reformat the graphs to a layout for the gui,
 and it contains the main class that creates the framework for the GUI (top bar etc.)
 """
+from platform import system
+
 import PySide6.QtCore as QtC
 import PySide6.QtGui as QtG
 import PySide6.QtWidgets as QtW
@@ -68,12 +70,12 @@ class BaseUI:
         size_policy.setHeightForWidth(ghe_tool.sizePolicy().hasHeightForWidth())
         ghe_tool.setSizePolicy(size_policy)
         ghe_tool.setMaximumSize(QtC.QSize(16777215, 16777215))
-        globs.FONT = QtG.QFont()
-        globs.FONT.setFamilies([globs.FONT])
-        globs.FONT.setPointSize(globs.FONT_SIZE)
-        globs.FONT.setBold(False)
-        globs.FONT.setItalic(False)
-        ghe_tool.setFont(globs.FONT)
+        font = QtG.QFont()
+        font.setFamily(globs.FONT)
+        font.setPointSize(globs.FONT_SIZE)
+        font.setBold(False)
+        font.setItalic(False)
+        ghe_tool.setFont(font)
         icon = QtG.QIcon()
         icon.addFile(f"{globs.FOLDER}/icons/{globs.ICON_NAME}", QtC.QSize(), QtG.QIcon.Normal, QtG.QIcon.Off)
         ghe_tool.setWindowIcon(icon)
@@ -533,3 +535,6 @@ class BaseUI:
         self.tool_bar.setWindowTitle("toolBar")
         self.status_bar_progress_bar.addPermanentWidget(self.frame_progress_bar, 1)
         self.status_bar_progress_bar.hide()
+        # hide toolbar if MAC
+        if system() == "Darwin":  # pragma: no cover
+            self.tool_bar.hide()
