@@ -13,13 +13,12 @@ from typing import TYPE_CHECKING
 import PySide6.QtCore as QtC
 import PySide6.QtGui as QtG
 import PySide6.QtWidgets as QtW
-
 import ScenarioGUI.global_settings as globs
 
 from .gui_base_class import BaseUI
 from .gui_calculation_thread import CalcProblem
 from .gui_data_storage import DataStorage
-from .gui_structure_classes import FigureOption, Option
+from .gui_structure_classes import FigureOption, Option, ResultExport
 from .gui_structure_classes.functions import check_aim_options, show_linked_options
 
 if TYPE_CHECKING:
@@ -229,7 +228,9 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         ]:
             option.change_event(self.change)
         for option, _ in [(opt, name) for opt, name in self.gui_structure.list_of_options if isinstance(opt, FigureOption)]:
-            option.change_event(self.remove_previous_calculated_results)
+            option.change_event(self.change_figure_option)
+        for option, _ in [(opt, name) for opt, name in self.gui_structure.list_of_result_exports]:
+            option.change_event(ft_partial(self.export_results, option))
         for option, _ in self.gui_structure.list_of_aims:
             option.change_event(self.change)
 
@@ -254,6 +255,22 @@ class MainWindow(QtW.QMainWindow, BaseUI):
         self.list_widget_scenario.itemSelectionChanged.connect(self._always_scenario_selected)
         self.dia.closeEvent = self.closeEvent
 
+    def export_results(self, result_export: ResultExport):
+        filename: tuple = QtW.QFileDialog.getSaveFileName(
+            self.central_widget,
+            caption=result_export.caption,
+            filter=f".{result_export.file_extension} (*.{result_export.file_extension})",
+            dir=str(self.default_path),
+        )
+        d_s = self.list_ds[self.list_widget_scenario.currentRow()]
+        getattr(d_s.results, result_export.export_function)(filename[0])
+
+    def change_figure_option(self):
+        d_s = self.list_ds[self.list_widget_scenario.currentRow()]
+        for option, name in [(opt, name) for opt, name in self.gui_structure.list_of_options if isinstance(opt, FigureOption)]:
+            setattr(d_s, name, option.get_value())
+        self.remove_previous_calculated_results()
+
     def remove_previous_calculated_results(self):
         """
         This function removes previously calculated results by removing the results attribute
@@ -1278,9 +1295,11 @@ class MainWindow(QtW.QMainWindow, BaseUI):
 
             fig = getattr(ds, fig_name)
             if fig is None:
+                globs.set_graph_layout()
                 # create axes and drawing
                 fig, ax_new = getattr(results, fig_obj.function_name)(**fig_obj.kwargs)
                 fig_obj.replace_figure(fig)
+                globs.set_graph_layout()
                 # show everything
                 fig_obj.show()
                 fig_obj.canvas.show()
@@ -1289,7 +1308,9 @@ class MainWindow(QtW.QMainWindow, BaseUI):
                 # set figure to datastorage
                 setattr(ds, fig_name, fig)
                 continue
+            globs.set_graph_layout()
             fig_obj.replace_figure(fig)
+            globs.set_graph_layout()
             # show everything
             fig_obj.show()
             fig_obj.canvas.show()
