@@ -4,6 +4,7 @@ It contains all the options, categories etc. that should appear on the GUI.
 """
 from __future__ import annotations
 
+import logging
 from typing import TYPE_CHECKING
 
 from ScenarioGUI.gui_classes.gui_structure_classes import (
@@ -16,7 +17,7 @@ from ScenarioGUI.gui_classes.gui_structure_classes import (
     ListBox,
     Option,
     Page,
-    ResultFigure,
+    ResultExport, ResultFigure,
     ResultText,
 )
 
@@ -65,6 +66,7 @@ class GuiStructure:
 
         self.list_of_result_texts: list[tuple[ResultText, str]] = []
         self.list_of_result_figures: list[tuple[ResultFigure, str]] = []
+        self.list_of_result_exports: list[tuple[ResultExport, str]] = []
 
         self.list_of_options_with_dependent_results: list[tuple[Option, str]] = []
 
@@ -132,11 +134,14 @@ class GuiStructure:
         self.list_of_result_figures: list[tuple[ResultFigure, str]] = [
             (getattr(self, name), name) for name in self.__dict__ if isinstance(getattr(self, name), ResultFigure)
         ]
-
+        self.list_of_result_exports: list[tuple[ResultExport, str]] = [
+            (getattr(self, name), name) for name in self.__dict__ if isinstance(getattr(self, name), ResultExport)
+        ]
         self.list_of_options_with_dependent_results: list[tuple[Option, str]] = [
             (getattr(self, name), name) for name in self.__dict__ if isinstance(getattr(self, name), Option) if getattr(self, name).linked_options
         ]
 
+
     def change_toggle_button(self) -> None:
         """
         This function changes the behaviour of both the ButtonBox and aim selection
@@ -172,4 +177,7 @@ class GuiStructure:
         Page.previous_label = translation.label_previous[index]
         for name in [j for j in translation.__slots__ if hasattr(self, j)]:
             entry: Option | Hint | FunctionButton | Page | Category = getattr(self, name)
-            entry.translate(index)
+            try:
+                entry.translate(index)
+            except IndexError:
+                logging.error(name)
